@@ -7,22 +7,16 @@
 #' @param shape String specifying plot shape. Either "circle" or "square"
 #' @param size Approximated size of sample plot. Equals the radius for circles or half of
 #' the side-length for squares in mapunits. For lines size equals the width of the buffer.
+#' @param transform Logical if planar CRS are transformed to lon/lat for accuracy during area
+#' calculations of buffer areas.
 #' @param verbose Print warning messages.
 #' @param progress Print progress report.
 #' @param ... Arguments passed on to \code{calculate_lsm()}.
 
 #' @details
-#' This function calculates the selected metrics in subsequential buffers around
-#' a/multiple point(s) of interest.
-#'
-#' The size of the actual sampled landscape can be different to the provided size
-#' due to two reasons. Firstly, because clipping raster cells using a circle or a
-#' sample plot not directly at a cell center lead to inaccuracies. Secondly,
-#' sample plots can exceed the landscape boundary. Therefore, we report the actual
-#' clipped sample plot area relative in relation to the theoretical, maximum sample
-#' plot area e.g. a sample plot only half within the landscape will have a
-#' `percentage_inside = 50`. Please be aware that the output is sligthly different
-#' to all other `lsm`-function of `landscapemetrics`.
+#' This function calculates the selected metrics in sub-sequential buffers around
+#' point(s) of interest. To see more details about arguments passed on to the metrics,
+#' please see `calculate_lsm()`.
 #'
 #' The metrics can be specified by the arguments `what`, `level`, `metric`, `name`
 #' and/or `type` (combinations of different arguments are possible (e.g.
@@ -30,6 +24,23 @@
 #' automatically all possibilities are selected. Therefore, to get **all**
 #' available metrics, don't specify any of the above arguments.
 #'
+#' For all metrics based on distances or areas please make sure your data is valid
+#' using \code{\link{check_landscape}}.
+#'
+#' Please be aware that the output is slightly different to all other `lsm`-function
+#' of `landscapemetrics`.
+#'
+#' The size of the actual sampled landscape can be different to the provided size
+#' due to two reasons. Firstly, because clipping raster cells using a circle or a
+#' sample plot not directly at a cell center lead to inaccuracies. Secondly, sample
+#' plots can exceed the landscape boundary. Therefore, we report the actual clipped
+#' sample plot area relative in relation to the theoretical, maximum sample plot
+#' area e.g. a sample plot only half within the landscape will have a `percentage_inside = 50`.
+#' Additionally, if the polygon representing the sample plot is smaller than the cell
+#' size of the raster, the `percentage_inside` may exceed 100%. To calculate the area of
+#' the buffer zones, the function `terra::expanse()` is used. The area results may
+#' be influenced by the CRS and the `transform` argument.
+#'
 #' @seealso
 #' \code{\link{list_lsm}} \cr
 #' \code{\link{calculate_lsm}} \cr
@@ -49,7 +60,7 @@
 #' @rdname scale_sample
 #'
 #' @export
-scale_sample <- function(landscape, y, shape = "square", size,
+scale_sample <- function(landscape, y, shape = "square", size, transform = TRUE,
                          verbose = TRUE, progress = FALSE, ...) {
 
     landscape <- landscape_as_list(landscape)
@@ -57,7 +68,7 @@ scale_sample <- function(landscape, y, shape = "square", size,
     result <- lapply(X = seq_along(landscape), FUN = function(x) {
         if (progress) {cat("\r> Progress nlayers: ", x , "/", length(landscape))}
         scale_sample_int_multibuffer(landscape = landscape[[x]], y = y,
-                                     shape = shape, size = size,
+                                     shape = shape, size = size, transform = transform,
                                      verbose = verbose, progress = FALSE,
                                      ...)
     })
@@ -81,7 +92,7 @@ scale_sample <- function(landscape, y, shape = "square", size,
     result[with(result, order(layer, plot_id, level, metric, class, id, size)), ]
 }
 
-scale_sample_int_multibuffer <- function(landscape, y, shape, size, verbose, progress, ...) {
+scale_sample_int_multibuffer <- function(landscape, y, shape, size, transform, verbose, progress, ...) {
 
     # loop through buffers
     result <- do.call(rbind, lapply(X = seq_along(size), FUN = function(x) {
@@ -89,9 +100,8 @@ scale_sample_int_multibuffer <- function(landscape, y, shape, size, verbose, pro
         # print progess using the non-internal name
         if (progress) {cat("\r> Progress scales: ", x, "/", length(size))}
 
-        scale_sample_int(landscape = landscape, y = y,
-                         shape = shape, size = size[[x]],
-                         verbose = verbose, ...)
+        scale_sample_int(landscape = landscape, y = y, shape = shape, size = size[[x]],
+                         transform = transform, verbose = verbose, ...)
     }))
 
     if (progress) {cat("\n")}
@@ -99,8 +109,7 @@ scale_sample_int_multibuffer <- function(landscape, y, shape, size, verbose, pro
     return(result)
 }
 
-scale_sample_int <- function(landscape, y, shape, size,
-                             verbose, progress, ...) {
+scale_sample_int <- function(landscape, y, shape, size, transform, verbose, progress, ...) {
 
     # check if y is spatial object
     if (inherits(x = y, what = c("sf", "sfc", "sfg", "SpatialPoints", "SpatialPolygons", "SpatVector"))) {
@@ -125,7 +134,7 @@ scale_sample_int <- function(landscape, y, shape, size,
     y <- construct_buffer(coords = y, shape = shape, size = size, crs = crs, verbose = verbose)
 
     # get area of all polygons
-    maximum_area <- suppressWarnings(terra::expanse(y)) / 10000
+    maximum_area <- suppressWarnings(terra::expanse(y, transform = transform)) / 10000
 
     # loop through each sample point and calculate metrics
     result <- do.call(rbind, lapply(X = seq_along(y), FUN = function(current_plot) {
