@@ -8,6 +8,6 @@ using namespace Rcpp;
 
 int triangular_index(int r, int c);
 
-NumericVector rcpp_get_coocurrence_vector(IntegerMatrix x, arma::imat directions, bool ordered = true);
+NumericVector rcpp_get_coocurrence_vector(const IntegerMatrix &x, arma::imat directions, bool ordered = true);
 
 #endif // GET_COOCURRENCE_VECTOR_H
