@@ -1,13 +1,10 @@
-context("class level lsm_c_iji metric")
-
 landscapemetrics_class_landscape_value <- lsm_c_iji(landscape)
 
 test_that("lsm_c_iji is typestable", {
 
-    expect_is(lsm_c_iji(landscape), "tbl_df")
-    expect_is(lsm_c_iji(landscape_stack), "tbl_df")
-    expect_is(lsm_c_iji(landscape_brick), "tbl_df")
-    expect_is(lsm_c_iji(landscape_list), "tbl_df")
+    expect_s3_class(lsm_c_iji(landscape), "tbl_df")
+    expect_s3_class(lsm_c_iji(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_c_iji(landscape_list), "tbl_df")
 })
 
 test_that("lsm_c_iji returns the desired number of columns", {
@@ -32,3 +29,14 @@ test_that("lsm_c_iji returns warning for less than 3 classes", {
                    fixed = TRUE)
 })
 
+test_that("lsm_c_iji equals FRAGSTATS", {
+    lsm_landscape <- lsm_c_iji(landscape) |> dplyr::pull(value)
+    lsm_augusta <- lsm_c_iji(augusta_nlcd) |> dplyr::pull(value)
+
+    fs_landscape <- dplyr::filter(fragstats_class, LID == "landscape", metric == "iji") |> dplyr::pull(value)
+    fs_augusta <- dplyr::filter(fragstats_class, LID == "augusta_nlcd", metric == "iji") |> dplyr::pull(value)
+
+    expect_true(test_relative(obs = lsm_landscape, exp = fs_landscape, tolerance = tol_rel))
+    expect_true(test_relative(obs = lsm_augusta, exp = fs_augusta, tolerance = tol_rel))
+})
+
