@@ -1,12 +1,9 @@
-context("landscape level lsm_l_cai_sd metric")
-
 landscapemetrics_landscape_landscape_value <- lsm_l_cai_sd(landscape)
 
 test_that("lsm_l_cai_sd is typestable", {
-    expect_is(lsm_l_cai_sd(landscape), "tbl_df")
-    expect_is(lsm_l_cai_sd(landscape_stack), "tbl_df")
-    expect_is(lsm_l_cai_sd(landscape_brick), "tbl_df")
-    expect_is(lsm_l_cai_sd(landscape_list), "tbl_df")
+    expect_s3_class(lsm_l_cai_sd(landscape), "tbl_df")
+    expect_s3_class(lsm_l_cai_sd(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_l_cai_sd(landscape_list), "tbl_df")
 })
 
 test_that("lsm_l_cai_sd returns the desired number of columns", {
