@@ -1,12 +1,9 @@
-context("landscape level lsm_l_relmutinf metric")
-
 landscapemetrics_landscape_landscape_value <- lsm_l_relmutinf(landscape)
 
 test_that("lsm_l_relmutinf is typestable", {
-    expect_is(lsm_l_relmutinf(landscape), "tbl_df")
-    expect_is(lsm_l_relmutinf(landscape_stack), "tbl_df")
-    expect_is(lsm_l_relmutinf(landscape_brick), "tbl_df")
-    expect_is(lsm_l_relmutinf(landscape_list), "tbl_df")
+    expect_s3_class(lsm_l_relmutinf(landscape), "tbl_df")
+    expect_s3_class(lsm_l_relmutinf(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_l_relmutinf(landscape_list), "tbl_df")
 })
 
 test_that("lsm_l_relmutinf returns the desired number of columns", {
@@ -21,4 +18,3 @@ test_that("lsm_l_relmutinf returns in every column the correct type", {
     expect_type(landscapemetrics_landscape_landscape_value$metric, "character")
     expect_type(landscapemetrics_landscape_landscape_value$value, "double")
 })
-
